@@ -132,6 +132,7 @@ Node::~Node(void)
      case HC_FILE         : delete ((DBFile      *)data); break;
      case HC_MP3TAG       : delete ((DBMp3Tag    *)data); break;
      case HC_CONTENT      : delete ((DBContent   *)data); break;
+     case HC_CATLNK       : delete ((DBCatLnk    *)data); break;
     }
    }
    child=next=NULL;
@@ -173,6 +174,7 @@ const char *Node::getNameOf(void)
      case HC_FILE         : return ((DBFile      *)data)->name; 
      case HC_MP3TAG       : return ""; 
      case HC_CONTENT      : return ""; 
+     case HC_CATLNK       : return ((DBCatLnk    *)data)->name;  
     }
    return "";   
  }
@@ -341,6 +343,29 @@ DBContent:: ~DBContent(void)
     storedSize = 0;
   }
 
+
+
+DBCatLnk::DBCatLnk(char *pname,char *plocation,char *pcomment)
+  {
+   name      = pname;
+   location  = plocation;
+   comment   = pcomment;
+  }
+   
+DBCatLnk::DBCatLnk(void)
+  {
+    name     = NULL;
+    location = NULL;
+    comment  = NULL;
+  }
+   
+DBCatLnk::~DBCatLnk(void)
+  {
+   if(name     != NULL) delete[] name;
+   if(comment  != NULL) delete[] comment;
+   if(location != NULL) delete[] location;   
+  }
+
 DataBase::DataBase(void)
  {
   nicef           = true;
@@ -499,7 +524,7 @@ int   DataBase::insertDB(char *filename)
 
   if(root==NULL)
    {
-    errormsg = tr("There is not opened database!");
+    errormsg = tr("No database opened!");
     return 1;    
    }
   progress(pww);
@@ -535,6 +560,7 @@ int   DataBase::insertDB(char *filename)
   delete fw;
   return 0;
  }
+
 /***************************************************************************/
 int   DataBase::openDB  (char *filename)
  {
@@ -901,6 +927,54 @@ int DataBase::scanFileProp(QFileInfo *fi,DBFile *fc)
   
   return 0;
  }
+ 
+void DataBase::addLnk(const char *loc)
+ {
+  char *catname = NULL;
+  gzFile f=NULL;
+  FileReader *fw = NULL;
+
+  Node *tmp=root->child,
+       *n = new Node(HC_CATLNK,root);
+
+  /* Reading database name from the pointed file */ 
+  f = gzopen(loc,"rb");
+  if(f==NULL)
+   {
+    QMessageBox::warning(NULL,tr("Error"),tr("I can't open the file: %1").arg(loc));
+    return;
+   }
+  
+  fw = new FileReader(f); 
+  catname=fw->getCatName(); 
+  if(catname==NULL) 
+   {
+    QMessageBox::warning(NULL,tr("Error"),tr("Error while parsing file: %1").arg(loc));
+    delete fw;
+    gzclose(f);
+    return;
+   }
+  gzclose(f);
+  delete fw;
+  /* end reading from the file */
+  
+  char *storedname = new char [ strlen(catname) +2 ];
+  sprintf(storedname,"@%s",catname);
+
+  n->data = new DBCatLnk(storedname,mstr(loc),NULL);
+  
+  if(root->child == NULL)
+   {
+    root->child = n;
+   }    
+  else
+   {
+    while(tmp->next != NULL) tmp = tmp->next;
+    tmp->next = n;
+   }    
+   
+   root->touchDB();
+ } 
 /***************************************************************************/
 void DataBase::deleteNode(Node *d)
  {
@@ -1000,6 +1074,7 @@ void DataBase::sortM(int mode)
   Node *step;
   void *data;
   int length; 
+  int type;
   int i,j;
  
   if(root==NULL) return;
@@ -1014,9 +1089,14 @@ void DataBase::sortM(int mode)
   for(i=0;i<length;i++)
     for(j=i;j<length;j++)
      {
+      if(getMOnPos(i)->type == HC_CATLNK )
+         continue;
+      else if (getMOnPos(j)->type == HC_CATLNK)
+       ; /* nothing */ 	 
+      else
+       { 
        switch(mode)
         {
-	
 	 case NUMBER: 
 	  if(((DBMedia *)(getMOnPos(i)->data))->number < 
              ((DBMedia *)(getMOnPos(j)->data))->number)
@@ -1041,16 +1121,20 @@ void DataBase::sortM(int mode)
 	   continue;
 	   break;
 	}
-
+       }
 	//swap
 	step = getMOnPos(i)->child;
 	data = getMOnPos(i)->data ;
+	type = getMOnPos(i)->type;
 
 	getMOnPos(i)->child = getMOnPos(j)->child;
 	getMOnPos(i)->data  = getMOnPos(j)->data;
+	getMOnPos(i)->type  = getMOnPos(j)->type;
 
 	getMOnPos(j)->child = step;
 	getMOnPos(j)->data  = data;
+	getMOnPos(j)->type  = type;
+	
      }
    root->touchDB();     
  }
@@ -1082,7 +1166,7 @@ char *getCurrentTime(void)
   QDate d;
   t = QTime::currentTime();
   d = QDate::currentDate();
-  sprintf(m,"%s.%d %d:%d %d",(const char *)
+    sprintf(m,/* "%s.%d %d:%d %d" */ "%s %02d %02d:%02d %d",(const char *)
     (shortMonthName0(d.month())),d.day(),t.hour(),t.minute(),d.year());
 
 
@@ -1096,7 +1180,7 @@ char *getTime(QDateTime dt)
   QDate d;
   t = dt.time();
   d = dt.date();
-  sprintf(m,"%s.%d %d:%d %d",(const char *)
+  sprintf(m,/* "%s.%d %d:%d %d" */ "%s %02d %02d:%02d %d",(const char *)
     (shortMonthName0(d.month())),d.day(),t.hour(),t.minute(),d.year());
 
   return recodeI(m,&dbb6);
@@ -1111,6 +1195,7 @@ Node * DataBase::getMediaNode(char *name)
    t=root->child; //first media  
    while(t != NULL)
     {
+     if(t->type != HC_MEDIA) continue;
      if(!strcmp(t->getNameOf(),name))
         return t;
      t=t->next;
@@ -1136,6 +1221,22 @@ Node * DataBase::putMediaNode(char *name,int number,char *owner,int type,char *c
     } 
    return n;
  }
+ 
+  Node * DataBase::getMediaNode(int id)
+ {
+   Node *t=NULL;
+   
+   t=root->child; //first media  
+   while(t != NULL)
+    {
+     if(((DBMedia *)(t->data))->number == id){
+//	  		std::cout << "media found." << endl;
+        return t;
+		}
+     t=t->next;
+    }
+  return NULL;    
+ }
 
 Node * DataBase::getDirectoryNode(Node *meddir,char *name)
  {
@@ -1144,6 +1245,7 @@ Node * DataBase::getDirectoryNode(Node *meddir,char *name)
    t=meddir->child;   
    while(t != NULL)
     {
+     if(t->type != HC_DIRECTORY) continue;
      if(!strcmp(t->getNameOf(),name))
         return t;
      t=t->next;
@@ -1177,6 +1279,7 @@ Node * DataBase::getFileNode(Node *directory,char *name)
    t=directory->child;   
    while(t != NULL)
     {
+     if(t->type != HC_FILE) continue;
      if(!strcmp(t->getNameOf(),name))
         return t;
      t=t->next;
