@@ -349,10 +349,23 @@ void exportCdcatDB::ok()
 	/* === header === */
 	if ( radioHtml->isChecked() ) {
 		outstring += "<html>\n";
-		outstring += " <!-- This file was generated by CdCat";
+		outstring += " <!-- This file was generated by CdCat ";
 		outstring += HOMEPAGE;
 		outstring += " -->\n";
-		outstring += "<head>\n<title> "+ tr( "Export from cdcat:" ) + " " + ( ( DBCatalog * ) ( ( p->getRootNode() ) ->data ) ) ->name + "</title>\n</head>\n";
+		outstring += "<head>\n";
+		outstring += "<title> "+ tr( "Export from cdcat:" ) + " " + ( ( DBCatalog * ) ( ( p->getRootNode() ) ->data ) ) ->name + "</title>\n";
+		outstring += "<style>\n";	// we're gonna define style for our html document		
+		outstring += ".m { color: red; }\n"; // m - media
+		outstring += ".f { color: blue; }\n"; // f - file
+		outstring += ".d { color: green; }\n"; // d - date
+		outstring += ".c { color: darkgray; }\n"; // c - comment	
+		outstring += "table { border-collapse: collapse; }"; // extremely usefull table feature, 
+		// this causes table border to collapse into 1px wide border
+		// and there is no need 4 putting "&nbsp;" instead " " (space) to display empty cells correcty
+		//  (in mozilla/ie.. konqueror does seem to handle this)
+		outstring += "</style>\n";		
+
+		outstring += "</head>\n";
 		outstring += "<body>\n";
 		if (checkExportTitle->isChecked())
 			outstring += "<h1>" + tr( "Export from cdcat:" ) + " " + ( ( DBCatalog * ) ( ( p->getRootNode() ) ->data ) ) ->name + "</h1>\n";
@@ -362,16 +375,16 @@ void exportCdcatDB::ok()
 			if (!checkOnlyMediaName->isChecked()) {
 				outstring += "<tr>";
 				if( checkExportMediaName->isChecked())
-					outstring += "<td><strong>" + tr( "Media" ) + "</strong></td>";
+					outstring += "<th>" + tr( "Media" ) + "</th>";
 				if( checkExportPath->isChecked())
-					outstring += "<td><strong>" + tr( "File" )+ "</strong></td>";
+					outstring += "<th>" + tr( "File" )+ "</th>";
 				;
 				if( checkExportSize->isChecked())
-					outstring += "<td><strong>" + tr( "Size" ) + "</strong></td>";
+					outstring += "<th>" + tr( "Size" ) + "</th>";
 				if( checkExportDate->isChecked())
-					outstring += "<td><strong>" + tr( "Date" ) + "</strong></td>";
+					outstring += "<th>" + tr( "Date" ) + "</th>";
 				if( checkExportComment->isChecked())
-					outstring += "<td><strong>" + tr( "Comment" ) + "</strong></td>";
+					outstring += "<th>" + tr( "Comment" ) + "</th>";
 
 				outstring += "</tr>\n";
 			} else {
@@ -567,7 +580,7 @@ int exportCdcatDB::writeMedia( Node *source )
 	if (radioHtml->isChecked() && checkOnlyMediaName->isChecked())
 	 {
 	   if ( inList ) 
-	      outstring += "<tr><td><font color=\"red\">" + medianame + "</font></td></tr>";  
+	      outstring += "<tr><td class=\"m\">" + medianame + "</td></tr>";  
          }	      
         else
  	    if ( inList ) 
@@ -624,37 +637,37 @@ int exportCdcatDB::writeFile( Node *source )
 
 	      //======== items ==========		   
                 if (checkExportMediaName->isChecked())
-  		      outstring += "<td><font color=\"red\">" + medianame + "</font></td>";  
+  		      outstring += "<td class=\"m\">" + medianame + "</td>";  
 		
 		if (checkExportPath->isChecked()) 
-		      outstring += "<td><font color=\"blue\">" + getFilePath( source ) + "</font></td>";
+		      outstring += "<td class=\"f\">" + getFilePath( source ) + "</td>";
 
 		if (checkExportSize->isChecked()) 
 		{
-	              outstring += "<td align=\"right\"><font color=\"black\">";
+	              outstring += "<td>";
                       outstring += QString().setNum( ( ( DBFile * ) ( source->data ) ) ->size );
 		      outstring +=" ";
 		      outstring += QString( getSType( ( ( ( DBFile * ) ( source->data ) ) ->sizeType ) ) );
-                      outstring += "</font></td>";
+                      outstring += "</td>";
 		}
 
 		if (checkExportDate->isChecked()) 
 		{
-		      outstring += "<td align=\"right\"><font color=\"green\">";
+		      outstring += "<td class=\"d\">";
                       outstring += QString( recode( ( ( DBFile * ) ( source->data ) ) ->modification, &out3 ) );
-                      outstring += "</font></td>";
+                      outstring += "</td>";
 		}
 
 		if (checkExportComment->isChecked() ) 
 		{
 		         
-                      outstring += "<td align=\"right\"><font color=\"darkgray\">";
+                      outstring += "<td class=\"c\">";
 		      if(((DBFile*)(source->data))->comment != NULL)
                         outstring += QString((( DBFile * ) ( source->data ) )->comment)
 			                       .replace(QRegExp("#"),"\n");
 		      else
-		       	outstring += " ";
-		      outstring += "</font></td>";
+		       	outstring += "";
+		      outstring += "</td>";
 		}
 
 	   outstring += "</tr>";  
