@@ -219,7 +219,7 @@ void findDialog::languageChange()
      cbAlbum->setText(    tr( "mp3-tag Album" ) );
      cbArtist->setText(   tr( "mp3-tag Artist" ) );
      cbTcomm->setText(    tr( "mp3-tag Comment" ) );
-     cbDirname->setText(  tr( "Directory name" ) );
+     cbDirname->setText(  tr( "Media / Directory name" ) );
      cbTitle->setText(    tr( "mp3-tag Title" ) );
      cbComment->setText(  tr( "Comment" ) );
      cbContent->setText(  tr( "Content" ) );
@@ -277,6 +277,12 @@ int findDialog::fillCBox(void)
   tmp=tmp->child; //Jump to the first media
   while(tmp != NULL)
    {
+    if(tmp->type != HC_MEDIA) 
+     {
+      tmp=tmp->next;
+      continue;
+     }
+     
     cbSin  ->insertItem(tmp->getNameOf());
     strcpy(ow,((DBMedia *)(tmp->data))->owner);
     c = cbOwner->count();
@@ -444,12 +450,30 @@ int seekEngine::analyzeNode(Node *n,Node *pa)
        case HC_MEDIA:
            progress(pww);
           
+	  //It is necessary to analyze this media node? /Owner/Media/
 	   if((allmedia || (strcmp(media,n->getNameOf())==0)) &&
               (allowner || (strcmp(owner,((DBMedia *)(n->data))->owner)==0))) 
+	       {
+	           if(dirname)  
+	            if(matchIt(n->getNameOf()))
+                     {
+	              putNodeToList(n);
+		      analyzeNode(n->child);    
+  	              analyzeNode(n->next);    
+                      return 0;
+	            }
+                   if(comment)
+	             if(matchIt(((DBMedia *)(n->data))->comment))
+	              putNodeToList(n);
+
                   analyzeNode(n->child);	   
-   
+	       }	  
            analyzeNode(n->next );	    	   
            return 0;
+
+       case HC_CATLNK:
+	   analyzeNode(n->next);       
+           return 0;
 	   
        case HC_DIRECTORY:
            progress(pww);
@@ -528,7 +552,7 @@ int seekEngine::analyzeNode(Node *n,Node *pa)
 	       }
 	   analyzeNode(n->next,pa);       
            return 0;
-       	   
+
     }
   return -1;
  } 
@@ -554,6 +578,10 @@ void seekEngine::putNodeToList(Node *n)
   
   switch(n->type)
    {
+    case HC_MEDIA:     strcpy(type,(const char *)tr("media"));
+                       strcpy(mod,((DBMedia *)(n->data))->modification);    
+        break;
+   
     case HC_DIRECTORY: strcpy(type,(const char *)tr("dir"));
                        strcpy(mod,((DBDirectory *)(n->data))->modification);    
         break;
@@ -572,8 +600,11 @@ void seekEngine::putNodeToList(Node *n)
   sprintf(media,"%s/%d",tmp->getNameOf(),((DBMedia *)(tmp->data))->number);      
   
   fd->resultsl->insertItem(new QListViewItem(fd->resultsl,
-                                            n->getNameOf(),type,media,
-					    n->getFullPath(),mod
+                                            n->getNameOf(),
+					    type,
+					    media,
+					    n->getFullPath(),
+					    mod
                                            ));
   progress(pww);					   
   founded++;
