@@ -14,6 +14,8 @@
 #include <qlabel.h>
 #include <qheader.h>
 #include <qpainter.h>
+
+#include <qregexp.h>
 #include <qpixmap.h>
 #include <qmessagebox.h>
 #include <qfiledialog.h>
@@ -31,6 +33,7 @@
 #include "guibase.h"
 #include "borrow.h"
 #include "mainwidget.h"
+#include "colorsettings.h"
 #include "dbase.h"
 #include "cdcat.h"
 #include "recode.h"
@@ -52,7 +55,7 @@
 
 char *rbuff=NULL;
 
-
+CdCatConfig *glob_conf;
 
 void GuiSlave::checkversion(QWidget *p,DataBase *db)
  {
@@ -67,10 +70,11 @@ void GuiSlave::checkversion(QWidget *p,DataBase *db)
     
   if(fv == "1.2") return;    
   if(fv == "1.3") return;
+  if(fv == "1.4") return;  
  
   QMessageBox::warning(p,tr("Warning..."),
       tr(
-"The database file has newer version than this version of cdcat knows:\n\
+"The database file has newer version than this version of cdcat can work with:\n\
 I understand maximum %1 datafile version but readed %2\n\n\
 Strongly recommended to upgrade your cdcat!!!\n\
 Homepage: %3").arg(DVERS).arg(fv).arg(HOMEPAGE)
@@ -83,6 +87,7 @@ GuiSlave::GuiSlave(CdCatMainWidget *p)
  {
   mainw=p;
 
+
   standON = NULL;
   tmpParent = NULL;
   if(mainw->db != NULL)
@@ -90,6 +95,7 @@ GuiSlave::GuiSlave(CdCatMainWidget *p)
      updateListFromNode(mainw->db->getRootNode());
      standOn(mainw->listView->currentItem());
    }
+  glob_conf = p->cconfig; 
  }
 
 void GuiSlave::updateStatusl(Node *n)
@@ -98,9 +104,9 @@ void GuiSlave::updateStatusl(Node *n)
   if(n == NULL)
    {
      if(mainw->db == NULL)
-        mainw->statusl->setText(tr("No opened database."));
+        mainw->statusl->setText(tr("No database opened."));
      else
-        mainw->statusl->setText(tr("No selected item."));
+        mainw->statusl->setText(tr("No item selected."));
      return;
    }     
   mainw->statusl->setText(n->getFullPath());
@@ -116,7 +122,8 @@ int GuiSlave::isIdentical(int i)
   t = t->child;
   while(t != NULL)
    {
-      if(((DBMedia *)(t->data))->number == i) return 0;
+      if(t->type == HC_MEDIA)
+        if(((DBMedia *)(t->data))->number == i) return 0;
    
       t = t->next;
    }
@@ -156,6 +163,7 @@ int GuiSlave::isIdentical(QString q)
   t = t->child;
   while(t != NULL)
    {
+     if(t->type == HC_MEDIA)
       if(strcmp(((DBMedia *)(t->data))->name,(const char *)q) == 0) return 0;
 
       t = t->next;
@@ -164,8 +172,6 @@ int GuiSlave::isIdentical(QString q)
  }
 
 
-
-
 Node *GuiSlave::getNodeFromFullName(Node *root,const QString& newloc)
  {
   int i=0,ki=0;
@@ -228,7 +234,7 @@ int GuiSlave::listUpdate(const QString& newloc)
 
 int GuiSlave::updateListFromNode(Node *pdir)
  {
-   int fflag=0;
+  int fflag=0;
    Node *tmp;
    HQListViewItem *lvi=NULL;
    char str1[128];
@@ -244,7 +250,19 @@ int GuiSlave::updateListFromNode(Node *pdir)
     }
 
    mainw->listView->clear();
-   mainw->listView->setSorting(-1);
+   mainw->listView->setSorting(mainw->listView->scol,mainw->listView->sasc);
+
+  //Set column text:
+   if(pdir != NULL && pdir->type == HC_CATALOG)
+    {
+     mainw->listView->setColumnText(1,tr("Number"));
+    }
+   else
+    {
+     mainw->listView->setColumnText(1,tr("Size"));
+    }    
+   
+   
    if(pdir->parent != NULL)
     {
      lvi = new HQListViewItem(mainw->listView,"..","",tr("Directory"));
@@ -263,11 +281,16 @@ int GuiSlave::updateListFromNode(Node *pdir)
         return 1; //Error
        
       // 2.(size) Column name:
+      
       if(tmp->type == HC_FILE)
        {
              sprintf(str1,"%.2f %s",((DBFile *)(tmp->data))->size,
 	          getSType(((DBFile *)(tmp->data))->sizeType));
        }
+      else if(tmp->type == HC_MEDIA)
+       {
+             sprintf(str1,"%d",((DBMedia *)(tmp->data))->number);
+       } 
       else
        {	
              sprintf(str1," ");	
@@ -290,13 +313,21 @@ int GuiSlave::updateListFromNode(Node *pdir)
                        case OTHERD  : strcpy(str2,tr("OtherDevice"));   break;
 		     }
 		break;
-         case HC_DIRECTORY: strcpy(str2,tr("Directory")); break;
-	 case HC_FILE:      strcpy(str2,tr("File"));      break;
+         case HC_DIRECTORY:   strcpy(str2,tr("Directory"));       break;
+	 case HC_FILE:        strcpy(str2,tr("File"));            break;
+	 case HC_CATLNK:      strcpy(str2,tr("Catalog Link"));    break;	 
        }
 
       lvi = new HQListViewItem(mainw->listView,tmp->getNameOf(),str1,str2);
 
-      lvi->etype = (tmp->type == HC_FILE ? 2 : 1 );      
+      switch(tmp->type)
+        {
+         case HC_CATALOG  : lvi->etype = 0;  break;
+	 case HC_MEDIA    : lvi->etype = 3;  break;
+         case HC_DIRECTORY: lvi->etype = 1;  break;
+	 case HC_FILE     : lvi->etype = 2;  break;
+	 case HC_CATLNK   : lvi->etype = (mainw->cconfig->linkf ? 0 : 4 );  break;	 
+       }
 
       switch(tmp->type)
        {
@@ -316,6 +347,7 @@ int GuiSlave::updateListFromNode(Node *pdir)
          break;
        case HC_DIRECTORY: lvi->setPixmap( 0,*get_v_folderclosed_icon());  break;
        case HC_FILE:      lvi->setPixmap( 0,*get_v_file_icon() );         break;  
+       case HC_CATLNK:    lvi->setPixmap( 0,*get_p_icon() );         break;         
      }
 
      if(tmpParent != NULL)/*Return to previous parent*/
@@ -331,7 +363,7 @@ int GuiSlave::updateListFromNode(Node *pdir)
      tmp=tmp->next;
     }
 
-   mainw->listView->setSorting(0);
+   mainw->listView->setSorting(mainw->listView->scol,mainw->listView->sasc);
 
    if(!fflag)
       mainw->listView->setCurrentItem(mainw->listView->firstChild());
@@ -394,6 +426,11 @@ int GuiSlave::doubleClickOn(QListViewItem *on)
          showContent();         
 	 return 0;    
 	}  
+       if(tmp->type == HC_CATLNK)	
+        {
+         followLnk();         
+	 return 0;    
+	}  
        NodePwd = tmp;
      } 
     updateListFromNode();     
@@ -449,6 +486,10 @@ void GuiSlave::showListviewContextMenu(QListViewItem *, const QPoint &p, int)
 
       if(haveContent(standON))
          mPopup->insertItem(*get_t_showc_icon(),tr("Show/Remove Content..."),this,SLOT(showContent()));
+
+      if(standON->type == HC_CATLNK)
+         mPopup->insertItem(*get_p_icon(),tr("Follow the link (Open it) !"),this,SLOT(followLnk()));
+	 
       mPopup->insertItem(tr("Rename node..."),this,SLOT(renameEvent()));
       mPopup->insertItem(*get_t_delete_icon() ,tr("Delete node"),this,SLOT(deleteEvent()));
       
@@ -468,6 +509,7 @@ void GuiSlave::showListviewContextMenu(QListViewItem *, const QPoint &p, int)
      }
     mPopup->insertSeparator(); 
     mPopup->insertItem(*get_t_add_icon() ,tr("Add media..."),this,SLOT(addEvent()));
+    mPopup->insertItem(*get_p_icon() ,tr("Add a link to a CdCAt Catalog..."),this,SLOT(addlnkEvent()));
     mPopup->insertItem(tr("Insert Catalog..."),this,SLOT(insertcEvent()));
     mPopup->exec(p);
     delete mPopup;
@@ -515,6 +557,7 @@ void GuiSlave::showTreeContextMenu(QListViewItem *, const QPoint &p2, int)
        }
      }
     mPopup->insertItem(*get_t_add_icon() ,tr("Add media..."),this,SLOT(addEvent()));
+    mPopup->insertItem(*get_p_icon() ,tr("Add a link to a CdCAt Catalog..."),this,SLOT(addlnkEvent()));
     mPopup->insertItem(tr("Insert Catalog..."),this,SLOT(insertcEvent()));
     if(on != NULL)
      {
@@ -537,6 +580,15 @@ void GuiSlave::showTreeContextMenu(QListViewItem *, const QPoint &p2, int)
  * 
 *****************************************************************************/
 
+void HQListViewItem::paintCell(QPainter *p,const QColorGroup & cg,int column,int width,int align)
+ {
+   QColorGroup ocg(cg);
+   ocg.setColor(QColorGroup::Highlight,*glob_conf->comm_bg);
+   ocg.setColor(QColorGroup::HighlightedText,QColor(black));
+   QListViewItem::paintCell(p,ocg,column,width,align);
+ }
+	  
+
 
 HQListViewItem::HQListViewItem(QListView *parent)
 :QListViewItem(parent)
@@ -582,6 +634,12 @@ QString HQListViewItem::key(int column,bool ascending) const
 	                              .rightJustify(10,'0'))
 				         .prepend('1'+mod); 
 	        } 
+	       if(etype == 3) //HC_MEDIA    	
+	        {
+		 return (QString().setNum(text(1).toInt()))
+		                                .rightJustify(10,'0')
+		                                  .prepend('1'+mod); 
+		}
 	       return text(0).prepend('1'+mod); 
     //TYPE	       
       case 2:  return (text(2).append(text(0))).prepend('1'+mod);
@@ -599,12 +657,11 @@ void HQListView::start(void)
  {
   ;
  }
-
+ 
 HQListView::HQListView(CdCatMainWidget *mw,QWidget *parent,const char *name,WFlags f)
 :QListView(parent,name,f)
  {
   mainw = mw;
-  
   setSelectionMode(Single);
   addColumn(tr("Name"));
   addColumn(tr("Size"));  
@@ -621,12 +678,22 @@ void HQListView::curr_vis(void)
     ensureItemVisible(i);
  }
 
+void HQListView::setSorting(int column, bool increasing)
+ {
+   scol = column;
+   sasc = increasing;
+
+   if(scol<0 || scol>3)  
+    scol = 0;
+
+   QListView::setSorting(scol,increasing);
+ } 
 
 int GuiSlave::hotKeys(QKeyEvent *ke)
  {
   switch(ke->key())
    {
-    case (Qt::Key_O) :     openEvent();    return 1;     
+/*  case (Qt::Key_O) :     openEvent();    return 1;     
     case (Qt::Key_N) :     newEvent();     return 1;         
     case (Qt::Key_C) :     closeEvent();   return 1;             
     case (Qt::Key_A) :     addEvent();     return 1;         
@@ -634,17 +701,14 @@ int GuiSlave::hotKeys(QKeyEvent *ke)
     case (Qt::Key_G) :     configEvent();  return 1;     
     case (Qt::Key_F) :     findEvent();    return 1;             
     case (Qt::Key_H) :     helpEvent();    return 1;
-    case (Qt::Key_Q) :     mainw->close(); return 1;     
-    case (Qt::Key_Escape) : mainw->close(); return 1;     
+    case (Qt::Key_Q) :     mainw->close(); return 1;
     case (Qt::Key_Space) :  sizeEvent();    return 1;
-    case (Qt::Key_S) :  
-                    if(ke->state() == Qt::ControlButton ||
-		       ke->state() == Qt::AltButton    )
-                           posEvent(); 
+*/     
+    case (Qt::Key_Escape) : mainw->close(); return 1;     
 
-		    else
-		        	   
-                           saveEvent();
+    case (Qt::Key_S) :  
+                    if(ke->state() == Qt::ControlButton)
+                           posEvent(); 
 	  	    return 1;     
    }
   return 0; 
@@ -696,6 +760,12 @@ void HQListView::keyPressEvent(QKeyEvent *ke)
 	  mainw->guis->showContent();
           return;    
 	 } 
+       if(tmp->type == HC_CATLNK)
+         {
+	  mainw->guis->followLnk();
+          return;    
+	 } 
+
        mainw->guis->NodePwd = tmp;
      }
 
@@ -729,7 +799,6 @@ int GuiSlave::newEvent(void)
   return 0;
  }
 
-
 int GuiSlave::openEvent(void)
  {
   char fnc[256];
@@ -772,13 +841,17 @@ int GuiSlave::openEvent(void)
   //QMessageBox::information(0,"new history element",fn);
   if (ret_val == 0 && !fn.isEmpty())
    {
-    mainw->cconfig->hlist.append(fn);
-    mainw->historyMenu->insertItem(*get_t_open_icon(),fn);
-    if ((int)mainw->cconfig->hlist.count() > (int)mainw->cconfig->historysize)
-     {
-         (mainw->cconfig->hlist).remove (mainw->cconfig->hlist.begin());
-         mainw->historyMenu->removeItemAt(0);
-     }
+   
+    if(mainw->cconfig->hlist.grep(QRegExp(QString("^")+QString(fn)+QString("$"))).isEmpty())
+     {   
+      mainw->cconfig->hlist.append(fn);
+      mainw->historyMenu->insertItem(*get_t_open_icon(),fn);
+      if ((int)mainw->cconfig->hlist.count() > (int)mainw->cconfig->historysize)
+       {
+          (mainw->cconfig->hlist).remove (mainw->cconfig->hlist.begin());
+          mainw->historyMenu->removeItemAt(0);
+       }
+     }  
    }
 
   progress(pww);
@@ -865,17 +938,24 @@ int GuiSlave::saveasEvent(void)
 
 int GuiSlave::closeEvent(void)
  {
+  int userrq=0;
   int retv=0;
   if(mainw->db == NULL) return 0;
   if(((DBCatalog *)(mainw->db->getRootNode()->data))->writed == 0 )
-    if(QMessageBox::warning(mainw,tr("Closing previous database..."),tr("Do you want to save the changes?"),
-        tr("Yes"),tr("No")) == 0)
-        if((retv=mainw->db->saveDB()) != 0)
-	 {
-	  if(retv==1) //The databas had no name.
-	     retv=saveasEvent();
-	  // retv can be nonrezo reasoned by saveDB or saveAsEvent too.     
-	 }  
+   {
+    userrq = QMessageBox::warning(mainw,tr("Closing previous database..."),tr("Do you want to save the changes?"),
+             tr("Yes"),tr("No"));
+
+    if(userrq == -1) retv = -1;
+
+    if(userrq == 0)
+         if((retv=mainw->db->saveDB()) != 0)
+	  {
+	   if(retv==1) //The databas had no name.
+	      retv=saveasEvent();
+	   // retv can be nonrezo reasoned by saveDB or saveAsEvent too.     
+	  }
+   }
   panelsOFF();
 
   /* Freeing database object */
@@ -921,7 +1001,6 @@ int GuiSlave::addEvent(void)
    if(mainw->db == NULL)
       return 0;
 
-
    addDialog *d=new addDialog(this,mainw,"adddialog",true);
    d->exec();
    
@@ -1003,6 +1082,18 @@ int GuiSlave::addEvent(void)
                             (char *)((const char *)d->dName),
 			    d->serial,d->type,
 			    (d->dOwner).isEmpty() ? NULL : ((char *)((const char *)(d->dOwner))));
+
+     //Do autosave if the user ask it in the config !
+     if(mainw->cconfig->autosave) 
+      {
+       int retv=0;			    
+       if((retv=mainw->db->saveDB()) != 0)
+         {
+          if(retv==1) //The databas had no name. need a save as...
+           retv=saveasEvent();
+         }
+      }
+      			    
      panelsON();
      if(i!=0)
       {
@@ -1156,6 +1247,18 @@ int GuiSlave::rescanEvent(void)
       mainw->db->deleteNode(standON);	    	          
      }    
     standON=NULL; 
+    
+    //Do autosave if the user ask it in the config !
+    if(mainw->cconfig->autosave) 
+      {
+       int retv=0;			    
+       if((retv=mainw->db->saveDB()) != 0)
+         {
+          if(retv==1) //The databas had no name. need a save as...
+           retv=saveasEvent();
+         }
+      }
+
     panelsON();
    
   progress(pww);
@@ -1286,7 +1389,7 @@ int GuiSlave::sizeEvent(void)
 				 .arg(mainw->db->getCountFiles(standON))
 				 .arg(mainw->db->getCountDirs (standON)); 			 
   
-  QMessageBox::information(mainw,tr("The Resoult:"),qtext,
+  QMessageBox::information(mainw,tr("The resoult:"),qtext,
                                            tr("Ok"),0);
   return 0;
  }
@@ -1425,6 +1528,78 @@ int GuiSlave::showContent(void)
   return 0;
  }
 
+int GuiSlave::addlnkEvent(void)
+ {
+   if(mainw->db == NULL) return 0;
+   
+   AddLnk *al = new AddLnk(mainw);
+   al->exec();
+   if(al->ok)
+    {
+     panelsOFF();
+     mainw->db->addLnk((const char *)al->fname->text());
+     panelsON();
+    } 
+   delete al;
+   cHcaption(); 															    
+   return 0;
+ }
+
+int GuiSlave::followLnk(void)
+ {
+  if(mainw->db == NULL) return 0;
+  if(standON->type == HC_CATLNK)
+   {
+    char fnc[256];
+
+    if( ((DBCatLnk *)(standON->data))->location == NULL ||
+       !strcmp(((DBCatLnk *)(standON->data))->location,""))
+        {
+	 QMessageBox::warning(mainw,tr("Error while opening..."),
+                          tr("The link is empty."),tr("Ok"),0);
+
+	 return 0;
+	}
+	 
+
+    int ret_val=0;
+
+    
+    strcpy(fnc,(const char *)((DBCatLnk *)(standON->data))->location);
+    while(closeEvent() !=0);
+    panelsOFF();
+
+    if(mainw->db == NULL)
+       mainw->db = new DataBase();
+
+    PWw *pww = new PWw(mainw,mainw->app);
+    mainw->db->pww = pww;
+    progress(pww);
+
+    if((ret_val=mainw->db->openDB(fnc)) != 0 )
+     { // An error occured
+       QMessageBox::warning(mainw,tr("Error while opening..."),
+                            mainw->db->errormsg,tr("Ok"),0);
+       mainw->db = NULL;
+       standON = NodePwd = NULL;
+       panelsOFF();
+     }
+  
+    checkversion(mainw,mainw->db); 
+
+    progress(pww);
+    panelsON();
+    progress(pww);
+
+    progress(pww);
+    pww->end();
+    if(mainw->db != NULL)
+       mainw->db->pww = NULL;
+    delete pww;
+   }    
+
+  return 0; 
+ }
 
 int GuiSlave::borrowingEvent(void)
  {
@@ -1578,4 +1753,15 @@ int GuiSlave::posEvent(void)
   return 0;
  }
 
+int GuiSlave::colorEvent(void)
+ {
+  ColorSettings *d;
+   
+  d=new ColorSettings(mainw->cconfig,mainw,"cs",true);
+  d->exec();
+  mainw->repaint();
+  mainw->commentWidget->repaint();
+  return 0;
+ }
+
 
