@@ -1,4 +1,31 @@
 <!DOCTYPE TS><TS>
+<context>
+    <name>AddLnk</name>
+    <message>
+        <source>Add a &quot;Catalog Link&quot; to the database</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Location of the .hcf file:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ok</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>CdCat databases (*.hcf )</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open a file...</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>CdCatConfig</name>
     <message>
@@ -15,10 +42,6 @@ Check the file, or change the autoload option in the config dialog!
         <source>Ok</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Error during write config...</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>I can&apos;t open the autoload catalog according the first command line parameter.
 Check the file!
@@ -38,13 +61,13 @@ It is necessary couse I&apos;d like to save the config file into your home direc
         <source>I can&apos;t create or rewrite the $(HOME)/.cdcatconfig file </source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Error while saving config file...</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CdCatMainWidget</name>
-    <message>
-        <source>No selected item</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Directory Tree</source>
         <translation type="unfinished"></translation>
@@ -165,10 +188,6 @@ It is necessary couse I&apos;d like to save the config file into your home direc
         <source>Add a new media to the catalog.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Rescan the selected media from the disk.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Delete the selected media from the catalog.</source>
         <translation type="unfinished"></translation>
@@ -221,6 +240,84 @@ It is necessary couse I&apos;d like to save the config file into your home direc
         <source>Save the catalog to a new file.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Add a link to a CdCAt Catalog...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set Colors...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No item selected</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rescan the selected media.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Seek in the panel</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ColorSchemePreview</name>
+    <message>
+        <source>Title:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Road To Hell</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ColorSettings</name>
+    <message>
+        <source>ColorSettings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Comment area background and the file higlighting line</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Frame of comment area</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Comment window static text (Program text)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Comment window variable text (Data)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>color</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Red:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Green:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Blue:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ok</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CommentWidget</name>
@@ -252,10 +349,6 @@ It is necessary couse I&apos;d like to save the config file into your home direc
         <source>Size:</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Last moification:</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Owner:</source>
         <translation type="unfinished"></translation>
@@ -296,6 +389,18 @@ It is necessary couse I&apos;d like to save the config file into your home direc
         <source>There is no selected element.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source> Link to a CdCat catalog</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Location:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Last modification:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ConfigDialog</name>
@@ -352,11 +457,15 @@ It is necessary couse I&apos;d like to save the config file into your home direc
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Select readable items</source>
+        <source>Choose a file to load automatically!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Choose a file to load automatically!</source>
+        <source>Automatically save the database after every scan (for dafety sake)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select additional items to read</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -370,10 +479,6 @@ It is necessary couse I&apos;d like to save the config file into your home direc
         <source>I can&apos;t create the file: %1</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>There is not opened database!</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>I can&apos;t open the file: %1</source>
         <translation type="unfinished"></translation>
@@ -398,6 +503,14 @@ It is necessary couse I&apos;d like to save the config file into your home direc
         <source>Symbolic link#Points to:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Error while parsing file: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No database opened!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>DirectoryView</name>
@@ -408,14 +521,6 @@ It is necessary couse I&apos;d like to save the config file into your home direc
 </context>
 <context>
     <name>GuiSlave</name>
-    <message>
-        <source>No opened database.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>No selected item.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Directory</source>
         <translation type="unfinished"></translation>
@@ -533,10 +638,6 @@ It is necessary couse I&apos;d like to save the config file into your home direc
         <source>Insert a database file...</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>The Resoult:</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>The size of &quot;%1&quot; : 
  %2 
@@ -647,13 +748,49 @@ the DataBase may be incomplete</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>The database file has newer version than this version of cdcat knows:
+        <source>Catalog Link</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Follow the link (Open it) !</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add a link to a CdCAt Catalog...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The link is empty.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Number</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Size</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The database file has newer version than this version of cdcat can work with:
 I understand maximum %1 datafile version but readed %2
 
 Strongly recommended to upgrade your cdcat!!!
 Homepage: %3</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>No database opened.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No item selected.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The resoult:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>HDirectoryView</name>
@@ -719,19 +856,6 @@ Homepage: %3</source>
         <source>Create new Database</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Seperator:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>This is the seperator in dataline
-&lt;path&gt;SEPERATOR&lt;size&gt;SEPERATOR&lt;date&gt;&lt;space&gt;&lt;time&gt;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Seperator in data line</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Cancel</source>
         <translation type="unfinished"></translation>
@@ -772,10 +896,6 @@ Homepage: %3</source>
         <source>Type</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>&amp;XML (gtktalog)</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>&lt;strong&gt;Please read the README_IMPORT before you import!&lt;/strong&gt;</source>
         <translation type="unfinished"></translation>
@@ -784,14 +904,6 @@ Homepage: %3</source>
         <source>xml files(*.xml)</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Correct bad style of gtktalog export</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Select the type of import</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Import CSV file</source>
         <translation type="unfinished"></translation>
@@ -801,34 +913,71 @@ Homepage: %3</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>File dialog for selecting file to import.</source>
+        <source>Correct bad style from gtktalog export</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Corrects bad output style of gtktalog.
-&lt;media&gt;SEPERATOR/&lt;dir&gt;/SEPERATOR/&lt;dir&gt;
+        <source>Separator:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This is the separator in dataline
+&lt;path&gt;SEPARATOR&lt;size&gt;SEPARATOR&lt;date&gt;&lt;space&gt;&lt;time&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Separator in data line</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Text (csv)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Gtktalog &amp;XML</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;WhereIsIt XML (classic)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select the type of import here</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select this for importing a text import (csv)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select this for importing a xml report generated frm gtktalog</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open the file dialog for selecting file to import.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Corrects bad output style from gtktalog.
+&lt;media&gt;SEPARATOR/&lt;dir&gt;/SEPARATOR/&lt;dir&gt;
  will be to
 &lt;media&gt;/&lt;dir&gt;/&lt;dir&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>&amp;Text (CSV)</source>
+        <source>You must be fill the &quot;Filename&quot; field!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Select this for importing text file (CSV)</source>
+        <source>You must be fill the &quot;Separator&quot; field!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Select this for importing a XML report generated with gtktalog</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>You must fill the &quot;Filename&quot; field!</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>You must fill the &quot;Seperator&quot; field!</source>
+        <source>all files(*.*)</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -883,7 +1032,7 @@ Homepage: %3</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Polish translation</source>
+        <source>AVI reader plugin &amp; Polish translation</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1018,10 +1167,6 @@ Homepage: %3</source>
         <source>Channels</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Samples/s</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Bitrate</source>
         <translation type="unfinished"></translation>
@@ -1034,6 +1179,10 @@ Homepage: %3</source>
         <source>Not a RIFF/AVI file OR header broken!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Sample/s</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SelReadable</name>
@@ -1096,10 +1245,6 @@ Homepage: %3</source>
         <source>Confirmation</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Are you sure want to delete this file&apos;s content from the database?</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Yes</source>
         <translation type="unfinished"></translation>
@@ -1140,6 +1285,10 @@ Homepage: %3</source>
         <source>Ok</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Sure to delete this file&apos;s content from the database?</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>addDialog</name>
@@ -1243,6 +1392,10 @@ Homepage: %3</source>
         <source>You haven&apos;t selected a directory! Please select one!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>The media name can&apos;t begin with the &quot;@&quot; character!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>borrowDialog</name>
@@ -1273,22 +1426,10 @@ Homepage: %3</source>
 </context>
 <context>
     <name>borrowingDialog</name>
-    <message>
-        <source>Borrwing info...</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Media borrowing info:</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Only show borrowed items</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Clear all borrowing</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Media</source>
         <translation type="unfinished"></translation>
@@ -1341,6 +1482,26 @@ Homepage: %3</source>
         <source>Are you sure want to clear all borrow?</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>I got it back!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&lt;&lt; </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Borrowing info...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show only borrowed items</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Clear all borrowing info</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>commentEdit</name>
@@ -1574,10 +1735,6 @@ Homepage: %3</source>
         <source>File name</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Directory name</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>mp3-tag Comment</source>
         <translation type="unfinished"></translation>
@@ -1626,6 +1783,10 @@ Homepage: %3</source>
         <source>Content</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Media / Directory name</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>helpDialog</name>
@@ -1672,7 +1833,7 @@ E-mail: hyperr@freemail.hu
     </message>
 </context>
 <context>
-    <name>importCsv</name>
+    <name>importGtktalogCsv</name>
     <message>
         <source>Import was successful.</source>
         <translation type="unfinished"></translation>
@@ -1714,6 +1875,10 @@ E-mail: hyperr@freemail.hu
         <source>file read error</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Could not read file</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Fatal error</source>
         <translation type="unfinished"></translation>
@@ -1726,25 +1891,21 @@ E-mail: hyperr@freemail.hu
         <source>file open error</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>importuser</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Could not read file</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Could not open file</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>importuser</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Importing CSV...</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
-    <name>importXml</name>
+    <name>importGtktalogXml</name>
     <message>
         <source>Importing XML...</source>
         <translation type="unfinished"></translation>
@@ -1799,6 +1960,58 @@ E-mail: hyperr@freemail.hu
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>importWhereIsItXml</name>
+    <message>
+        <source>Importing XML...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Importing XML from WhereIsIt was successful.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>1 media</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>media</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>1 directory:,
+</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>directories</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>1 File</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>are imported.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Import successful</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>parse error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>error during parsing</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>newdbdialog</name>
     <message>
@@ -1833,6 +2046,10 @@ E-mail: hyperr@freemail.hu
         <source>Cancel</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source></source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source> </source>
         <translation type="unfinished"></translation>
@@ -1868,6 +2085,10 @@ E-mail: hyperr@freemail.hu
         <source>The new (media) name must be unique!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>The new media name can&apos;t starts with &quot;@&quot; !</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>renumberdialog</name>
@@ -1900,11 +2121,11 @@ E-mail: hyperr@freemail.hu
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>I Cannot understand the text as number!</source>
+        <source>The new media-number must be unique!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>The new media-number must be unique!</source>
+        <source>Please enter number value!</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1934,5 +2155,9 @@ E-mail: hyperr@freemail.hu
         <source>error</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>media</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
