@@ -27,6 +27,7 @@
  */
 #include <iostream.h>
 #include <stdio.h>
+#include <malloc.h>
 #include <qstring.h>
 
 #include "tparser.h"
@@ -254,7 +255,7 @@ unsigned int allcCount=0;/*temportarily used for additional data stored after wa
 
 QString parseAviHeader(FILE* file){
 	rewind(file); /*fseek(stream, 0L, SEEK_SET);*/
-	QString ReturnData;
+	QString ReturnData="";
 	/*
 	 *Load Data
 	 *Since these are structs, we can point at the beginning and 
@@ -403,7 +404,9 @@ QString parseAviHeader(FILE* file){
 	listDW.hex=0x0;
 	while(listDW.hex!=LIST){
 		fread((void*)&listDW.txt[0],sizeof(char),1,file);
-		if((int)listDW.txt[0]==0x4c)fread((void*)&listDW.txt[1],sizeof(char),1,file);
+		if((int)listDW.txt[0]==EOF)  return ReturnData;
+		if((int)listDW.txt[0]==0x4c)
+		    fread((void*)&listDW.txt[1],sizeof(char),1,file);
 		if((int)listDW.txt[1]==0x49){
 			fread((void*)&listDW.txt[2],sizeof(char),1,file);
 			};
@@ -420,6 +423,7 @@ QString parseAviHeader(FILE* file){
 		listDW.hex=0x00000000; /*clear data*/
 		while(listDW.hex!=LIST){
 			fread((void*)&listDW.txt[0],sizeof(char),1,file);
+			if((int)listDW.txt[0]==EOF)  return ReturnData;
 			if((int)listDW.txt[0]==0x4c)fread((void*)&listDW.txt[1],sizeof(char),1,file);
 			if((int)listDW.txt[1]==0x49){
 				fread((void*)&listDW.txt[2],sizeof(char),1,file);
@@ -537,7 +541,7 @@ QString parseAviHeader(FILE* file){
 	ReturnData+="\n";
 	fourccSwitch2(waveH.wFormatTag.hex, ReturnData);
 	ReturnData+=QObject::tr("Channels")  + QString(" = %1 \n").arg(waveH.nChannels);
-	ReturnData+=QObject::tr("Samples/s") + QString(" = %1kHz \n").arg((float)waveH.nSamplesPerSec/1000,0,'f',1); /*use waveH.nSamplesPerSec if you want to*/
+	ReturnData+=QObject::tr("Sample/s") + QString(" = %1kHz \n").arg((float)waveH.nSamplesPerSec/1000,0,'f',1); /*use waveH.nSamplesPerSec if you want to*/
 	ReturnData+=QObject::tr("Bitrate")   + QString(" = %1 kBit\n").arg((waveH.nAvgBytesPerSec*8)/1000);
 	
 	ReturnData+="\n";
