@@ -142,20 +142,23 @@ int  FileWriter::writeDown(Node *source)
   int i=0;
   switch(source->type)
    {
-    case 0: return 1;
-    case 1: writeHeader(); 
-            i=writeCatalog(source);
-    break;
-    case 2: i=writeMedia(source);    
-    break;
-    case 3: i=writeDirectory(source);    
-    break;
-    case 4: i=writeFile(source);    
-    break;
-    case 5: i=writeMp3Tag(source);    
-    break;
-    case 6: i=writeContent(source);    
-    break;
+    case HC_UNINITIALIZED: return 1;
+    
+    case HC_CATALOG:       writeHeader(); 
+                           i=writeCatalog(source);
+                           break;
+    case HC_MEDIA:         i=writeMedia(source);    
+                           break;
+    case HC_DIRECTORY:     i=writeDirectory(source);    
+                           break;
+    case HC_FILE:          i=writeFile(source);    
+                           break;
+    case HC_MP3TAG:        i=writeMp3Tag(source);    
+                           break;
+    case HC_CONTENT:       i=writeContent(source);    
+                           break;
+    case HC_CATLNK:        i=writeCatLnk(source);    
+                           break;
 
    }  
    return i;
@@ -292,6 +295,21 @@ int  FileWriter::writeContent(Node *source)
   return 0;
  }
 
+int  FileWriter::writeCatLnk(Node *source)
+ {
+  progress(pww);
+  gzprintf(f,"%s<catlnk name=\"%s\" location=\"%s\" >\n",
+            spg(level),
+            (recode(((DBCatLnk *)(source->data))->name,&out1)) + 1, //to remove the leading @
+	    recode(((DBCatLnk *)(source->data))->location,&out3));
+  
+  commentWriter(((DBCatLnk *)(source->data))->comment);
+  gzprintf(f,"%s</catlnk>\n",spg(level));      	    
+ 
+  if(source->next  != NULL) writeDown(source->next);
+  return 0; 
+ }
+
 /*****************************************************************************
  READING FILE:
 *****************************************************************************/
@@ -467,6 +485,18 @@ static void start(void *data, const char *el, const char **attr)
        
        tc1 = FREA->getStr  (attr,"name"  ,"Error while parsing \"media\" node");
        if(FREA->error) return;	 	        
+       if(tc1[0] == '@')
+        {
+	  FREA->errormsg = QString(
+"Line %1: The media name begin with \"@\".\n\
+It is disallowed since cdcat version 0.98 !\n\
+Please change it with an older version or rewrite it in the xml file!")
+	                    .arg(XML_GetCurrentLineNumber(*pp));
+			    
+	  FREA->error = 1;
+	  return;
+	} 
+       
        strcpy(newname,tc1);
        
        newnum = (int)FREA->getFloat (attr,"number","Error while parsing \"media\" node");
@@ -532,6 +562,18 @@ static void start(void *data, const char *el, const char **attr)
       tc4 = FREA->getStr  (attr,"type"  ,"Error while parsing \"media\" node");
       tc5 = FREA->getStr  (attr,"time"  ,"Error while parsing \"media\" node");
       if(FREA->error) return;
+      
+      if(tc2[0] == '@')
+        {
+	  FREA->errormsg = QString(
+"Line %1: The media name begin with \"@\".\n\
+It is disallowed since cdcat version 0.98 !\n\
+Please change it with an older version or rewrite it in the xml file!")
+	                    .arg(XML_GetCurrentLineNumber(*pp));
+	  FREA->error = 1;
+	  return;
+	} 
+      
       ti1 = getTypeFS(tc4);
       if(ti1 == UNKNOWN)
 	 {
@@ -634,6 +676,33 @@ static void start(void *data, const char *el, const char **attr)
     /*I don't make this node to the actual node because this won't be parent.*/
    }
 
+ if(!strcmp(el,"catlnk"))
+   {
+    char *memname;
+    Node *tt = FREA->sp->child;
+    
+    if(tt == NULL) FREA->sp->child = tt = new Node(HC_CATLNK,FREA->sp);
+    else
+     {
+      while(tt->next != NULL) tt = tt->next;
+      tt->next =  new Node(HC_CATLNK,FREA->sp);
+      tt=tt->next; 
+     }    
+    /*Fill data part:*/
+    tc1 = mstr(FREA->getStr (attr,"name"  ,"Error while parsing \"catlnk\" node"));
+    tc2 = mstr(FREA->getStr (attr,"location" ,"Error while parsing \"catlnk\" node"));
+    if(FREA->error) return;
+    
+    memname = new char[strlen(tc1) + 2];
+    sprintf(memname,"@%s",tc1);
+    delete [] tc1;
+    
+    tt->data = (void *) new DBCatLnk(memname,tc2,NULL);
+    
+    /*Make this node to the actual node:*/
+    FREA->sp = tt;   
+   }
+
  if(!strcmp(el,"content"))
    {
     /*nothing*/
@@ -688,6 +757,11 @@ static void end(void *data, const char *el)
       tmp_tagp->comment = mstr(FREA->dataBuffer);		
     tmp_tagp = NULL;
    }
+ if(!strcmp(el,"catlnk"))
+   {
+    /*Restore the parent node tho the actual node:*/
+    FREA->sp = FREA->sp->parent;     
+   }
 
  if(!strcmp(el,"content"))
   {
@@ -728,6 +802,9 @@ static void end(void *data, const char *el)
       case HC_FILE     : 
           ((DBFile      *)(FREA->sp->data)) -> comment = mstr(FREA->dataBuffer);
          break;
+      case HC_CATLNK   : 
+          ((DBCatLnk    *)(FREA->sp->data)) -> comment = mstr(FREA->dataBuffer);
+         break;
       case HC_MP3TAG:
 	  FREA->errormsg = QString("Line %1: It isnt allowed comment node in mp3tag node.")
 	                           .arg(XML_GetCurrentLineNumber(*pp));
@@ -745,6 +822,7 @@ static void end(void *data, const char *el)
       case HC_DIRECTORY: 
       case HC_FILE     : 
       case HC_MP3TAG   :      
+      case HC_CATLNK   :            
 	  FREA->errormsg = QString("Line %1: The borrow node only allowed in media node.")
 	                           .arg(XML_GetCurrentLineNumber(*pp));
           FREA->error = 1;
@@ -845,6 +923,62 @@ int FileReader::readFrom(Node *source)
   }
 }
 
+/* ********************************************************************* */
+char *catname;
+
+static void gn_start(void *data, const char *el, const char **attr) 
+ {
+  if(!strcmp(el,"catalog"))
+   {
+    catname = mstr(FREA->getStr(attr,"name","Error while parsing \"catalog\" node")); 
+   }
+ }  
+
+static void gn_end(void *data, const char *el) 
+ {
+ }
+
+char * FileReader::getCatName(void)
+ {
+  catname = NULL;
+  char *Buff = new char[BUFFSIZE];
+  XML_Parser p = XML_ParserCreate(NULL);
+                
+  if (p == NULL)
+   {
+    delete [] Buff;
+    return NULL;
+   }
+
+  XML_SetUserData(p,this);
+  XML_SetElementHandler(p, gn_start, gn_end);
+  for (;;) 
+  {
+    int done;
+    int len;
+
+    len = gzread(f,Buff,BUFFSIZE);
+    if (len == -1)
+     {
+      delete [] Buff;
+      return NULL;
+     }
+
+    done = gzeof(f);
+    if (! XML_Parse(p, Buff, len, done)) 
+     {
+      delete [] Buff;
+      return NULL;
+     }
+
+    if(done || catname != NULL)
+     {
+      delete [] Buff;
+      return mstr(catname);
+     } 
+  }
+ }
+
 
   
 
